package org.apache.bcel.generic;

import org.apache.bcel.classfile.ConstantCP;
import org.apache.bcel.classfile.ConstantNameAndType;
import org.apache.bcel.classfile.ConstantPool;
import org.apache.bcel.classfile.Utility;

/* loaded from: org_apache_bcel_generic.jar:org/apache/bcel/generic/FieldOrMethod.class */
public abstract class FieldOrMethod extends CPInstruction implements LoadClass {
    /* JADX INFO: Access modifiers changed from: package-private */
    public FieldOrMethod() {
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public FieldOrMethod(short opcode, int index) {
        super(opcode, index);
    }

    @Deprecated
    public String getClassName(ConstantPoolGen cpg) {
        ConstantPool cp = cpg.getConstantPool();
        ConstantCP cmr = cp.getConstant(super.getIndex());
        String className = cp.getConstantString(cmr.getClassIndex(), (byte) 7);
        if (className.startsWith("[")) {
            return "java.lang.Object";
        }
        return Utility.pathToPackage(className);
    }

    @Deprecated
    public ObjectType getClassType(ConstantPoolGen cpg) {
        return ObjectType.getInstance(getClassName(cpg));
    }

    @Override // org.apache.bcel.generic.LoadClass
    public ObjectType getLoadClassType(ConstantPoolGen cpg) {
        ReferenceType rt = getReferenceType(cpg);
        if (rt instanceof ObjectType) {
            return (ObjectType) rt;
        }
        throw new ClassGenException(rt.getClass().getCanonicalName() + " " + rt.getSignature() + " does not represent an ObjectType");
    }

    public String getName(ConstantPoolGen cpg) {
        ConstantPool cp = cpg.getConstantPool();
        ConstantCP cmr = cp.getConstant(super.getIndex());
        ConstantNameAndType cnat = cp.getConstant(cmr.getNameAndTypeIndex());
        return cp.getConstant(cnat.getNameIndex()).getBytes();
    }

    public ReferenceType getReferenceType(ConstantPoolGen cpg) {
        ConstantPool cp = cpg.getConstantPool();
        ConstantCP cmr = cp.getConstant(super.getIndex());
        String className = cp.getConstantString(cmr.getClassIndex(), (byte) 7);
        if (className.startsWith("[")) {
            return (ArrayType) Type.getType(className);
        }
        return ObjectType.getInstance(Utility.pathToPackage(className));
    }

    public String getSignature(ConstantPoolGen cpg) {
        ConstantPool cp = cpg.getConstantPool();
        ConstantCP cmr = cp.getConstant(super.getIndex());
        ConstantNameAndType cnat = cp.getConstant(cmr.getNameAndTypeIndex());
        return cp.getConstant(cnat.getSignatureIndex()).getBytes();
    }
}
